# "fix" lua underlinking:
%define _disable_ld_no_undefined 1

%define major 1
%define libname %mklibname lxc %{major}
%define develname %mklibname lxc -d

%global luaver 5.2
%global lualibdir %{_libdir}/lua/%{luaver}
%global luapkgdir %{_datadir}/lua/%{luaver}

Name:		lxc
Epoch:		1
Version:	2.0.0
Release:	%mkrel 5
Summary:	Linux Containers
URL:		http://linuxcontainers.org
Source0:	http://linuxcontainers.org/downloads/%{name}-%{version}.tar.gz
Patch0:         lxc-1.1.0-fix-init.patch
Patch1:         lxc-1.1.4-fix-bootorder.patch
Patch2:         lxc-2.0.0-remove-werror.patch
# Mga patches:
Patch10:	add-mga-support.patch
Group:		System/Kernel and hardware
License:	LGPLv2
BuildRequires:	docbook-utils
BuildRequires:	docbook-dtd30-sgml
BuildRequires:  docbook2x
BuildRequires:  doxygen
BuildRequires:	kernel-headers
BuildRequires:	pkgconfig(libseccomp)
BuildRequires:	libcap-devel
BuildRequires:  pkgconfig(lua)
BuildRequires:  python3-devel >= 3.2
BuildRequires:	systemd-devel
BuildRequires:	graphviz
Conflicts:	%{mklibname lxc 0} < 1:1.0.0
# lxc-extra subpackage not needed anymore, lxc-ls has been rewriten in
# C and does not depend on the Python3 binding anymore
Provides:       lxc-extra = %{epoch}:%{version}-%{release}
Obsoletes:      lxc-extra < 1:1.1.5-7

%{!?_pkgdocdir: %global _pkgdocdir %_defaultdocdir/%name}

%description
The package "%{name}" provides the command lines to create and manage
containers.  It contains a full featured container with the isolation
/ virtualization of the pids, the ipc, the utsname, the mount points,
/proc, /sys, the network and it takes into account the control groups.
It is very light, flexible, and provides a set of tools around the
container like the monitoring with asynchronous events notification,
or the freeze of the container. This package is useful to create
Virtual Private Server, or to run isolated applications like bash or
sshd.

%package -n	%{libname}
Summary:	Library for LXC
Group:		System/Libraries

%description -n %{libname}
Library for the Linux Kernel Containers.

%package        -n python3-%{name}
Summary:        Python binding for %{name}
Group:          Development/Python

%description    -n python3-%{name}
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The python3-%{name} package contains the Python3 binding for %{name}.

%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}_lxc\\..*\\.so


%package        -n lua-%{name}
Summary:        Lua binding for %{name}
Group:          Development/Other
Requires:       lua-filesystem

%description    -n lua-%{name}
Linux Resource Containers provide process and resource isolation without the
overhead of full virtualization.

The lua-%{name} package contains the Lua binding for %{name}.

%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}core\\.so\\.0

%package -n	%{develname}
Summary:	Development files for LXC
Group:		Development/C

%description -n %{develname}
Development files for the Linux Kernel Containers.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains documentation for %{name}.


%prep
%setup -q -n %{name}-%{version}
%autopatch -p1


%build
# (tv) for mga patch:
./autogen.sh
%configure2_5x F77=no \
           --enable-doc \
           --enable-api-docs \
           --disable-silent-rules \
           --docdir=%{_pkgdocdir} \
           --disable-rpath \
           --disable-apparmor \
           --enable-seccomp \
           --enable-lua \
           --enable-python \
           --with-init-script=systemd \

%make_build


%install
%{make_install}
chmod -x %{buildroot}%{luapkgdir}/lxc.lua

mkdir -p %{buildroot}%{_pkgdocdir}
cp -a AUTHORS README %{!?_licensedir:COPYING} %{buildroot}%{_pkgdocdir}
mkdir -p %{buildroot}%{_pkgdocdir}/api
cp -a doc/api/html/* %{buildroot}%{_pkgdocdir}/api/

# cache dir
mkdir -p %{buildroot}%{_localstatedir}/cache/%{name}

%find_lang %{name} --with-man

install -d %{buildroot}%{_datadir}/bash-completion/completions/
mv %{buildroot}%{_sysconfdir}/bash_completion.d/%{name} \
  %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%check
make check


%files -f %{name}.lang
%{_bindir}/lxc-*
%{_sbindir}/*lxc*
%{_libexecdir}/lxc
%{_datadir}/lxc
%{_mandir}/man*/%{name}*
%{_mandir}/*/man*/%{name}*
%{_sysconfdir}/lxc/default.conf
%{_sysconfdir}/default/lxc
%{_sharedstatedir}/lxc
%{_libdir}/lxc/rootfs
%{_unitdir}/lxc-net.service
%{_unitdir}/%{name}@.service
%{_unitdir}/lxc.service
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}
%dir %{_localstatedir}/cache/%{name}
%{_sharedstatedir}/%{name}

%files -n %{libname}
%dir %{_pkgdocdir}
%{_pkgdocdir}/AUTHORS
%{_pkgdocdir}/README
%license COPYING
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{major}.*
%dir %{_libdir}/lxc

%files -n python3-%{name}
%{python3_sitearch}/*

%files -n lua-%{name}
%{lualibdir}/%{name}
%{luapkgdir}/%{name}.lua

%files -n %{develname}
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/lxc
%{_libdir}/liblxc.so

%files doc
%dir %{_pkgdocdir}
# README, AUTHORS and COPYING intentionally duplicated because -doc
# can be installed on its own.
%{_pkgdocdir}/*
%if 0%{?_licensedir:1}
%license COPYING
%endif


%changelog
* Fri Apr 22 2016 tv <tv> 1:2.0.0-5.mga6
+ Revision: 1004679
- really adjusb obsoletes

* Fri Apr 22 2016 tv <tv> 1:2.0.0-4.mga6
+ Revision: 1004551
- adjusb obsoletes

* Thu Apr 21 2016 tv <tv> 1:2.0.0-3.mga6
+ Revision: 1004194
- really fix upgrade (epoch!)

* Thu Apr 21 2016 tv <tv> 1:2.0.0-2.mga6
+ Revision: 1004116
- fix upgrade: conflicts with lxc-extra instead of just provides+obsoletes

  + philippem <philippem>
    - add BR on graphviz

* Thu Apr 21 2016 tv <tv> 1:2.0.0-1.mga6
+ Revision: 1004054
- adjust file list
- rediff mga support patch
- update to 2.0.0
- obsolete the -extra subpackage
- move the completion file to %%{_datadir}

* Thu Mar 31 2016 tv <tv> 1:1.1.5-6.mga6
+ Revision: 997053
- own cache dir
- run testsuite
- add a doc package
- add patches from FC
- enable lua bindings
- use standard macros for building
- enable seccomp support
- simpler solution for rpath error
- onw include directory

* Wed Mar 30 2016 tv <tv> 1:1.1.5-4.mga6
+ Revision: 996817
- enable python bindings
- split tools now using python instead of shell in extra pkg

* Tue Mar 29 2016 tv <tv> 1:1.1.5-2.mga6
+ Revision: 996303
- BR ssystemd-devel
- explicitely specify we use systemd (though it's now autocomputed as part of mga support)
- add a mageia template
- adjust file list for systemd

* Tue Mar 29 2016 tv <tv> 1:1.1.5-1.mga6
+ Revision: 996289
- new release

* Mon Feb 15 2016 umeabot <umeabot> 1:1.1.4-2.mga6
+ Revision: 961314
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 joequant <joequant> 1:1.1.4-1.mga6
+ Revision: 894362
- upgrade to 1.1.4

* Thu Oct 22 2015 luigiwalser <luigiwalser> 1:1.0.5-6.mga6
+ Revision: 894299
- rediff patch from opensuse to fix CVE-2015-1335

* Tue Oct 20 2015 tv <tv> 1:1.0.5-5.mga6
+ Revision: 893158
- fix build: package more docs

* Mon Jul 27 2015 luigiwalser <luigiwalser> 1:1.0.5-4.mga6
+ Revision: 858315
- add upstream patches to fix CVE-2015-1331 and CVE-2015-1334

* Wed Oct 15 2014 umeabot <umeabot> 1:1.0.5-3.mga5
+ Revision: 745826
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:1.0.5-2.mga5
+ Revision: 682063
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 sander85 <sander85> 1:1.0.5-1.mga5
+ Revision: 661498
- New version: 1.0.5

* Mon Jun 16 2014 sander85 <sander85> 1:1.0.4-1.mga5
+ Revision: 637608
- New version: 1.0.4

* Fri May 16 2014 tv <tv> 1:1.0.3-1.mga5
+ Revision: 622964
- adjust file list
- new release

* Wed Feb 26 2014 blino <blino> 1:1.0.0-4.mga5
+ Revision: 597457
- fix again conflicts by using older libname

* Wed Feb 26 2014 blino <blino> 1:1.0.0-3.mga5
+ Revision: 597283
- fix conflict with lib package by using epoch

* Mon Feb 24 2014 tv <tv> 1:1.0.0-2.mga5
+ Revision: 596160
- fix unversioned file in library package (mga#12864)

* Sun Feb 23 2014 tv <tv> 1:1.0.0-1.mga5
+ Revision: 595958
- workaround find_lang failure with --with-man
- adjust file list
- bump major
- fix files listed twice
- drop merged patches
- new release
- new URL

* Thu Feb 13 2014 luigiwalser <luigiwalser> 1:0.9.0-6.mga5
+ Revision: 590883
- rediff upstream patch to fix CVE-2013-6441

* Mon Jan 13 2014 danf <danf> 1:0.9.0-5.mga4
+ Revision: 566524
- Added destroy-check.patch to prevent damage if a container is destroyed
  without being completely stopped
- Packaged missing /var/lib/lxc

* Sun Dec 29 2013 boklm <boklm> 1:0.9.0-4.mga4
+ Revision: 563089
- Fix location of rootfs directory

* Fri Nov 08 2013 boklm <boklm> 1:0.9.0-3.mga4
+ Revision: 549914
- Build man pages
- Install templates in default directory

* Sat Oct 19 2013 umeabot <umeabot> 1:0.9.0-2.mga4
+ Revision: 523897
- Mageia 4 Mass Rebuild

* Sun May 26 2013 tv <tv> 1:0.9.0-1.mga4
+ Revision: 427786
- fix install
- adjust file list
- new release

* Mon Apr 01 2013 tv <tv> 1:0.8.0-1.mga3
+ Revision: 407033
- new release
- disable apparmor (fix build)
- adjust filelist
- add epoch due to bogus prior packaging

* Sun Jan 13 2013 luigiwalser <luigiwalser> 0.8.0rc2-3.mga3
+ Revision: 362115
- make use of _libexecdir and fix files list

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 bcornec <bcornec> 0.8.0rc2-2.mga3
+ Revision: 316437
- Force a new release tag for lxc to have it rebuilt with the new tar file
- Update bad tar source file for lxc
- Update to upstream 0.8.0-rc2

* Sun Sep 04 2011 misc <misc> 0.7.5-1.mga2
+ Revision: 138350
- fix group and summary of lxc-devel
- obsoletes the lxc-doc package, as it is just 16 kb
- remove useless BuildRequires
- do not regenerate configure without reason
- comment the rpath stuff
- drop uneeded define
- new version, thanks bogdano for noticing

* Wed Jun 29 2011 tv <tv> 0.7.4.2-1.mga2
+ Revision: 116124
- fix build
- Buildrequires:  docbook-dtd30-sgml
- BR kernel-headers instead of kernel-devel-latest
- new release
- fix group for doc package

  + ahmad <ahmad>
    - define path to kernel src dir manually

  + boklm <boklm>
    - rebuild for bug #497

* Mon Mar 07 2011 saispo <saispo> 0.7.4-2.mga1
+ Revision: 65992
- Bump release
- Fix template installation
- Add doc and fix build
- New release 0.7.4

  + boklm <boklm>
    - add SOURCES directory
    - add lxc

